@@ -13,8 +13,10 @@ fi
 
 clean
 $SUDO pip2 install -r dev-requirements.txt
-python2.7 pytest_run.py willie test
+python2.7 pytest_run.py sopel test
 clean
 $SUDO pip3 install -r dev-requirements.txt
-python3 pytest_run.py willie test
+python3 pytest_run.py sopel test
+clean
 ./checkstyle.sh
+clean
