@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # coding=utf-8
-from __future__ import absolute_import
+from __future__ import unicode_literals, absolute_import, print_function, division
 # Different from setuptools script, because we want the one in this dir.
 from sopel import run_script
 run_script.main()
