@@ -4,10 +4,12 @@ ipython.py - sopel ipython console!
 Copyright © 2014, Elad Alfassa <elad@fedoraproject.org>
 Licensed under the Eiffel Forum License 2.
 
-Sopel: http://sopel.chat/
+Sopel: https://sopel.chat/
 """
 from __future__ import unicode_literals, absolute_import, print_function, division
+
 import sopel
+import sopel.module
 import sys
 if sys.version_info.major >= 3:
     # Backup stderr/stdout wrappers
