@@ -99,7 +99,7 @@ def setup(bot):
 
             # clean unmatched parentheses/braces/brackets
             for (opener, closer) in [('(', ')'), ('[', ']'), ('{', '}'), ('<', '>')]:
-                if url[-1] is closer and url.count(opener) < url.count(closer):
+                if (url[-1] == closer) and (url.count(opener) < url.count(closer)):
                     url = url[:-1]
 
             return url
@@ -166,7 +166,7 @@ def title_auto(bot, trigger):
         if bot.memory['safety_cache'][trigger]['positives'] > 1:
             return
 
-    urls = find_urls(trigger)
+    urls = find_urls(trigger, clean=True)
     if len(urls) == 0:
         return
 
