@@ -8,7 +8,7 @@ from __future__ import unicode_literals, absolute_import, print_function, divisi
 import random
 import re
 import requests
-from sopel.modules.search import google_search
+from sopel.modules.search import bing_search
 from sopel.module import commands, url
 
 ignored_sites = [
@@ -28,19 +28,19 @@ sites_query = ' site:xkcd.com -site:' + ' -site:'.join(ignored_sites)
 
 def get_info(number=None, verify_ssl=True):
     if number:
-        url = 'http://xkcd.com/{}/info.0.json'.format(number)
+        url = 'https://xkcd.com/{}/info.0.json'.format(number)
     else:
-        url = 'http://xkcd.com/info.0.json'
+        url = 'https://xkcd.com/info.0.json'
     data = requests.get(url, verify=verify_ssl).json()
-    data['url'] = 'http://xkcd.com/' + str(data['num'])
+    data['url'] = 'https://xkcd.com/' + str(data['num'])
     return data
 
 
 def google(query):
-    url = google_search(query + sites_query)
+    url = bing_search(query + sites_query)
     if not url:
         return None
-    match = re.match('(?:https?://)?xkcd.com/(\d+)/?', url)
+    match = re.match(r'(?:https?://)?xkcd.com/(\d+)/?', url)
     if match:
         return match.group(1)
 
@@ -87,7 +87,7 @@ def xkcd(bot, trigger):
     say_result(bot, requested)
 
 
-def numbered_result(bot, query, latest, verify_ssl):
+def numbered_result(bot, query, latest, verify_ssl=True):
     max_int = latest['num']
     if query > max_int:
         bot.say(("Sorry, comic #{} hasn't been posted yet. "
@@ -117,7 +117,7 @@ def say_result(bot, result):
     bot.say(message)
 
 
-@url('xkcd.com/(\d+)')
+@url(r'xkcd.com/(\d+)')
 def get_url(bot, trigger, match):
     verify_ssl = bot.config.core.verify_ssl
     latest = get_info(verify_ssl=verify_ssl)
